@@ -25,12 +25,13 @@ BASE_PROMPT += "then ask for the definition of the code and it will be provided.
 
 
 
+PAIR_MODEL = os.environ.get("PAIR_MODEL", "gpt-4")
+print("PAIR_MODEL =", PAIR_MODEL)
 
 chat_ctx = ChatContext(min_response_tokens=800,  # leave room for at least this much
                        max_response_tokens=None, # don't limit the model's responses
-                       max_context_assistant_messages=20,
-                       max_context_user_messages=20,    
-                       model=os.environ.get("PAIR_MODEL", "gpt-4"),
+                       chat_context_messages=20,
+                       model=PAIR_MODEL,
                        temperature=0.1,
                        base_system_msg_text=BASE_PROMPT)
     
@@ -152,7 +153,7 @@ def repl():
             sys.stdout.write(cr.delta)
             sys.stdout.flush()
         
-        print_formatted_text(FormattedText([("fg:olive", f"({cr.input_tokens} + {cr.response_tokens} tokens = ${cr.price:.4f})  ")]))
+        print_formatted_text(FormattedText([("fg:olive", f"\n({cr.input_tokens} + {cr.response_tokens} tokens = ${cr.price:.4f})  ")]))
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  ")
         # check response text for a diff 
         diff_match = re.search(r'```diff(.*?)```', cr.text, re.DOTALL)
